package net.unoh.snow;

import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

public class SnowManager extends Thread {

	private static final long FPS = 1000 / 25;

	private static final int INIT_SNOW_COUNT = 1;

	private SnowCanvas canvas = null;

	private List<Snow> snows = null;

	private WindListener windListener = null;

	private boolean enabled = true;

	public SnowManager(SnowCanvas canvas, WindListener windListener) {
		this.canvas = canvas;
		this.windListener = windListener;
		snows = Collections.synchronizedList(new LinkedList<Snow>());
	}

	public void run() {
		while (enabled) {
			updateSnows();
			addNewSnows();
			canvas.setSnows(snows);
			canvas.repaint();
			try {
				sleep(FPS);
			} catch (InterruptedException e) {
				e.printStackTrace();	// ignore
			}
		}
	}

	public void setEnabled(boolean enabled) {
		this.enabled = enabled;
	}

	protected void addNewSnows() {
		for (int i = 0; i < INIT_SNOW_COUNT; i++) {
			snows.add(new Snow());
		}
	}

	protected void updateSnows() {

		int direction = windListener.getDirection();

		for (int i = 0; i < snows.size(); i++) {

			Snow snow = snows.get(i);

			if (snow.isLanding()) {

				snows.remove(i);

			} else {

				snow.fall();
				snow.shakeHorizon();

				switch (direction) {
				case WindListener.DIRECTION_LEFT:
					snow.windLeft();
					break;
				case WindListener.DIRECTION_RIGHT:
					snow.windRight();
					break;
				case WindListener.DIRECTION_NONE:
					break;
				default:
					break;
				}
			}
		}

	}

}
